@@ -48,11 +48,11 @@ static inline string psym(const string& s, bool local = false)
     return s;
 }
 
-static inline const string& pname(int32_t f)
+static string pname(int32_t f)
 {
   assert(f > 0);
-  if (f == interpreter::g_interp->symtab.neg_sym().f) {
-    static string uminus = "-";
+  if (interpreter::g_interp->symtab.is_neg_sym(f)) {
+    string uminus = interpreter::g_interp->symtab.neg_sym_pname(f);
     return uminus;
   } else {
     const symbol& sym = interpreter::g_interp->symtab.sym(f);
@@ -86,10 +86,8 @@ static inline const string sym_padding(int32_t f)
 static prec_t sym_nprec(int32_t f)
 {
   assert(f > 0);
-  if (f == interpreter::g_interp->symtab.neg_sym().f) {
-    prec_t p = nprec(interpreter::g_interp->symtab.minus_sym().prec);
-    if (p < NPREC_MAX) p += 3; // precedence of unary minus
-    return p;
+  if (interpreter::g_interp->symtab.is_neg_sym(f)) {
+    return interpreter::g_interp->symtab.neg_sym_nprec(f);
   } else {
     const symbol& sym = interpreter::g_interp->symtab.sym(f);
     return nprec(sym.prec, sym.fix);
@@ -917,6 +915,7 @@ ostream& operator << (ostream& os, const pure_paren& p)
 static inline bool pstr(ostream& os, pure_expr *x)
 {
   static bool recursive = false;
+  if (!x) return false;
   if (recursive ||
       // We don't want to force a thunk here. Unfortunately, this means that
       // currently you can't define a print representation for a thunk, at
@@ -928,7 +927,6 @@ static inline bool pstr(ostream& os, pure_expr *x)
   map<int32_t,GlobalVar>::iterator it;
   if (f > 0 && (it = interp.globalvars.find(f)) != interp.globalvars.end() &&
       it->second.x && it->second.x->tag >= 0 && it->second.x->data.clos) {
-    assert(x->refc > 0);
     pure_aframe *ex = interp.push_aframe(interp.sstk_sz);
     if (setjmp(ex->jmp)) {
       // caught an exception
@@ -943,21 +941,27 @@ static inline bool pstr(ostream& os, pure_expr *x)
       recursive = false;
       return false;
     } else {
+      bool ret = false;
       recursive = true;
+      // The argument expression may well be a temporary if we're being
+      // invoked internally, so make sure that it doesn't get collected
+      // prematurely.
+      pure_ref(x);
       pure_expr *y = pure_app(it->second.x, x);
       interp.pop_aframe();
       recursive = false;
-      assert(y);
-      if (y->tag == EXPR::STR) {
-	char *s = fromutf8(y->data.s);
+      if (y) {
+	if (y->tag == EXPR::STR) {
+	  char *s = fromutf8(y->data.s);
+	  if (s) {
+	    os << s; free(s);
+	    ret = true;
+	  }
+	}
 	pure_freenew(y);
-	if (s) {
-	  os << s; free(s);
-	  return true;
-	} else
-	  return false;
-      } else
-	return false;
+      }
+      pure_unref(x);
+      return ret;
     }
   } else
     return false;
