@@ -2,7 +2,7 @@
 /* The Pure main program. This is currently rather simplistic. See the README
    file and the man page for details. */
 
-/* Copyright (c) 2008-2013 by Albert Graef <Dr.Graef@t-online.de>.
+/* Copyright (c) 2008-2017 by Albert Graef <aggraef@gmail.com>.
 
    The Pure main program is free software: you can redistribute it and/or
    modify it under the terms of the GNU General Public License as published by
@@ -96,7 +96,7 @@ using namespace std;
 #define PURELIB "/usr/local/lib/pure-" PACKAGE_VERSION
 #endif
 
-#define COPYRIGHT "Copyright (c) 2008-2014 by Albert Graef"
+#define COPYRIGHT "Copyright (c) 2008-2017 by Albert Graef"
 #define USAGE \
 "Usage:            pure [options ...] [-x] script [args ...]\n\
                   pure [options ...] [-b|-c|-i] [script ...] [-- args ...]\n\
@@ -597,6 +597,10 @@ main(int argc, char *argv[])
 	cout << "Pure " << PACKAGE_VERSION << " (" << HOST << ") "
 	     << COPYRIGHT << '\n';
 	cout << "Compiled for LLVM " << LLVM_VERSION << " (http://llvm.org)\n";
+#ifdef GITREVISION
+	if (strcmp(GITREVISION, "unknown"))
+	  cout << "Revision " << GITREVISION << '\n';
+#endif
 	return 0;
       } else if (strcmp(arg, "-b") == 0) {
 	batch = true; force_interactive = false;
