@@ -3,7 +3,7 @@
    is provided to be used freely under a BSD-style license, see below, as a
    starting point for your own interpreter frontends. */
 
-/* Copyright (c) 2009-2013 by Albert Graef <Dr.Graef@t-online.de>.
+/* Copyright (c) 2009-2017 by Albert Graef <aggraef@gmail.com>.
 
    All rights reserved.
 
@@ -60,7 +60,7 @@ using namespace std;
 #define PURELIB "/usr/local/lib/pure-" PACKAGE_VERSION
 #endif
 
-#define COPYRIGHT "Copyright (c) 2008-2014 by Albert Graef"
+#define COPYRIGHT "Copyright (c) 2008-2017 by Albert Graef"
 #define USAGE \
 "Usage:            pure [options ...] [-x] script [args ...]\n\
                   pure [options ...] [-b|-c|-i] [script ...] [-- args ...]\n\
@@ -278,6 +278,10 @@ main(int argc, char *argv[])
 	cout << "Pure " << PACKAGE_VERSION << " (" << HOST << ") "
 	     << COPYRIGHT << '\n';
 	cout << "Compiled for LLVM " << LLVM_VERSION << " (http://llvm.org)\n";
+#ifdef GITREVISION
+	if (strcmp(GITREVISION, "unknown"))
+	  cout << "Revision " << GITREVISION << '\n';
+#endif
 	return 0;
       } else if (strcmp(arg, "-b") == 0) {
 	batch = true; force_interactive = false;
